pecos.foreign\_objects.object\_pool
===================================

.. automodule:: pecos.foreign_objects.object_pool











   .. rubric:: Classes

   .. autosummary::

      NamedObjectPool
